=============================
yafa
=============================

.. image:: https://badge.fury.io/py/yafa_grpc.png
    :target: http://badge.fury.io/py/yafa_grpc

.. image:: https://travis-ci.org/gcrowell/yafa_grpc.png?branch=master
    :target: https://travis-ci.org/gcrowell/yafa_grpc

Stock trading backtesting with grpc


Features
--------

* TODO

